hw functions for the SOLID slow control

Dependents:   S_SCTRL_e_test SPItest sscm

Revision:
13:3d82f8e27414
Parent:
12:467def75b457
Child:
14:ee02872b282b
--- a/S_SCTRL_SM1_hwfunct.cpp	Thu Oct 23 17:25:45 2014 +0000
+++ b/S_SCTRL_SM1_hwfunct.cpp	Wed Nov 19 23:17:57 2014 +0000
@@ -4,7 +4,8 @@
  * ver 1.20   added serialnr read
  * ver 1.22   defined cs lines to inactive in safe settings
  * ver 1.30   added CAL puls function   
  * ver 1.31   added CAL line lvl  function   
  */
 
 #include "mbed.h"
@@ -12,7 +13,7 @@
 #include "S_SCTRL_SM1_hwfunct.h"
 
 
-#define HW_LIB_SRC_VERSION "1.31"
+#define HW_LIB_SRC_VERSION "1.32"
 
 #define MAXLIBVERCHAR 100  // max char for lib version 
 
@@ -191,3 +192,7 @@
     }
     return snr;
 }
+
+
+float Bias2Dac(float biasvolt){  return biasvolt/26.35507246 ; /* no correct implementation */  };
+float Dac2Bias(float dacvolt)  { return dacvolt*26.35507246;  /* no correct implementation */ };
\ No newline at end of file
@@ -4,7 +4,8 @@
  * ver 1.22   defined cs lines to inactive in safe settings
  * ver 1.30   added CAL puls function   
- * ver 1.31   added CAL line lvl  function   
+ * ver 1.31   added CAL line lvl  function 
+ * ver 1.32  added bias2dac voltage  and dac2bias  
  */
 